Assess
=================================================================
Analytical Solutions for the Stokes Equations in Spherical Shells
-----------------------------------------------------------------

Assess is a python package that implements a number of analytical solutions to
the Stokes equations in cylindrical and spherical shell domains. The eight
different cases are described in `link to gmd-paper <https://assess.readthedocs.io>`_.

Installation
============

Assess is a standard python package that can be installed from pypi:

    pip install assess

Documentation
=============

For usage instructions and a complete API reference see https://assess.readthedocs.io
